# Semgrep Registry Security Rules

This directory stores rules that originated from the semgrep registry (semgrep.dev/explore).

If a rule is prefixed with "jellyfish" that means we made modifications to it.

To locate the original rule in the registry:

1. Strip "jellyfish" from the rule file name (if applicable)
2. Search for the remaining file name (without the extension) in https://semgrep.dev/r